@@ -24,13 +24,16 @@ time.sleep(.3)
 
 #LT.set_loadlevel(load,lvl)
 
-#LT.set_loadon(load)
+LT.set_loadon(load)
 LT.get_led_state(kb)
+#LT.set_clock()
 #LT.set_loadoff(load)
 
 
 
 print('Waiting for Messages')
+time.sleep(30)
+LT.get_led_state(kb)
 time.sleep(10)
 
 print('Close Connection')
